"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.transitionIn = exports.onMount = void 0;

var _preact = require("preact");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * @param {(props: any) => void} fn
 * @param {any | import('preact').Component} startingState
 * @param {import('preact').Component | null} ChildComponent
 * @returns {import('preact').Component}
 */
const onMount = (fn, startingState, ChildComponent) => {
  // if we only got two args
  if (!ChildComponent) {
    ChildComponent = startingState;
    startingState = null;
  }

  class ModifiedComponent extends _preact.Component {
    constructor(props) {
      super(props);

      if (!ChildComponent && startingState) {
        this.state = startingState;
      }
    }

    componentDidMount() {
      fn(this.props);
    }

    render() {
      return (0, _preact.h)(ChildComponent, _objectSpread(_objectSpread({}, this.props), this.state));
    }

  }

  return ModifiedComponent;
};
/**
 * @param {import('preact').Component} OriginalComponent
 * @returns {import('preact').Component}
 */


exports.onMount = onMount;

const transitionIn = OriginalComponent => onMount(component => {
  setTimeout(() => {
    component.setState({
      firstRender: false
    });
  }, 0);
}, {
  firstRender: true
}, OriginalComponent);

exports.transitionIn = transitionIn;